import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixDevcenterCheckoutV1PurchasedItem from './devcenter-checkout-v1-purchased-item-billing.http.js';
export var PaymentCycle;
(function (PaymentCycle) {
    PaymentCycle["NO_CYCLE"] = "NO_CYCLE";
    PaymentCycle["MONTHLY"] = "MONTHLY";
    PaymentCycle["YEARLY"] = "YEARLY";
    PaymentCycle["ONE_TIME"] = "ONE_TIME";
    PaymentCycle["TWO_YEARS"] = "TWO_YEARS";
    PaymentCycle["THREE_YEARS"] = "THREE_YEARS";
    PaymentCycle["FOUR_YEARS"] = "FOUR_YEARS";
    PaymentCycle["FIVE_YEARS"] = "FIVE_YEARS";
})(PaymentCycle || (PaymentCycle = {}));
export var InvoiceStatus;
(function (InvoiceStatus) {
    InvoiceStatus["UNKNOWN_INVOICE_STATUS"] = "UNKNOWN_INVOICE_STATUS";
    InvoiceStatus["PAYMENT_FAILED"] = "PAYMENT_FAILED";
    InvoiceStatus["PAID"] = "PAID";
    InvoiceStatus["REFUNDED"] = "REFUNDED";
    InvoiceStatus["VOIDED"] = "VOIDED";
    InvoiceStatus["CHARGEDBACK"] = "CHARGEDBACK";
})(InvoiceStatus || (InvoiceStatus = {}));
export var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (WebhookIdentityType = {}));
/**
 * Retrieves the URL for a Wix checkout page for the specified paid plan of your app.
 *
 *
 * This call succeeds only in case you have previously
 * [set up an external pricing page in your app's dashboard](https://dev.wix.com/docs/build-apps/build-your-app/pricing-plans/set-up-an-external-pricing-page).
 *
 * The returned checkout URL is valid for 48 hours.
 *
 * This API allows your app to manage your pricing page outside of Wix while
 * still using the standard Wix checkout flow.
 * @param productId - ID of your app's paid plan to retrieve the Wix checkout URL for. Check your app's dashboard
 * for a list of your app's supported product IDs.
 * @public
 * @requiredField productId
 * @permissionId WIX_DEVELOPERS.CREATE_CHECKOUT
 * @permissionScope Manage Your App
 * @permissionScopeId SCOPE.DC.MANAGE-YOUR-APP
 * @permissionScope Read site, business, and email details
 * @permissionScopeId SCOPE.DEV_CENTER.APP-INSTANCE-READ-BASIC-INFO
 * @applicableIdentity APP
 * @fqn com.wixpress.market.aim.api.Checkout.GetUrl
 */
export async function getUrl(productId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        productId: productId,
        successUrl: options?.successUrl,
        testCheckout: options?.testCheckout,
        billingCycle: options?.billingCycle,
        countryCode: options?.countryCode,
        languageCode: options?.languageCode,
        couponCode: options?.couponCode,
    });
    const reqOpts = ambassadorWixDevcenterCheckoutV1PurchasedItem.getUrl(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                productId: '$[0]',
                successUrl: '$[1].successUrl',
                testCheckout: '$[1].testCheckout',
                billingCycle: '$[1].billingCycle',
                countryCode: '$[1].countryCode',
                languageCode: '$[1].languageCode',
                couponCode: '$[1].couponCode',
            },
            singleArgumentUnchanged: false,
        }, ['productId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Retrieves a list of the site owner's past purchases for your app.
 *
 *
 * You don't have to explicitly pass an identifier for the Wix site as part of
 * the request, since this information is taken automatically from the context.
 *
 * The response doesn't include any details about cancellations.
 * @public
 * @permissionId WIX_DEVELOPERS.APP_PURCHASE_HISTORY
 * @permissionScope Manage Your App
 * @permissionScopeId SCOPE.DC.MANAGE-YOUR-APP
 * @permissionScope Read site, business, and email details
 * @permissionScopeId SCOPE.DEV_CENTER.APP-INSTANCE-READ-BASIC-INFO
 * @applicableIdentity APP
 * @fqn com.wixpress.market.aim.api.Checkout.GetPurchaseHistory
 */
export async function getPurchaseHistory() {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[0];
    const payload = renameKeysFromSDKRequestToRESTRequest({});
    const reqOpts = ambassadorWixDevcenterCheckoutV1PurchasedItem.getPurchaseHistory(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {},
            singleArgumentUnchanged: false,
        }, []);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Triggers Wix to call the
 * [List Custom Charges SPI](https://dev.wix.com/docs/rest/internal-only/premium/custom-charges-spi/custom-charges-provider-v1/list-charges).
 *
 *
 * Wix doesn't use the response from _List Charges_ SPI to actually create an
 * invoice that's sent to the customer. Instead, calling _Get Metered Billing Charges_
 * allows you confirm that your integration with the Custom Charges SPI is
 * working as intended.
 * @internal
 * @documentationMaturity preview
 * @permissionId WIX_DEVELOPERS.METERED_BILLING_CHARGES_READ
 * @permissionScope Manage Your App
 * @permissionScopeId SCOPE.DC.MANAGE-YOUR-APP
 * @permissionScope Read site, business, and email details
 * @permissionScopeId SCOPE.DEV_CENTER.APP-INSTANCE-READ-BASIC-INFO
 * @applicableIdentity APP
 * @fqn com.wixpress.market.aim.api.Checkout.GetMeteredBillingCharges
 */
export async function getMeteredBillingCharges(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        currency: options?.currency,
        startDate: options?.startDate,
        endDate: options?.endDate,
    });
    const reqOpts = ambassadorWixDevcenterCheckoutV1PurchasedItem.getMeteredBillingCharges(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                currency: '$[0].currency',
                startDate: '$[0].startDate',
                endDate: '$[0].endDate',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=devcenter-checkout-v1-purchased-item-billing.universal.js.map