"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getMeteredBillingCharges = exports.getPurchaseHistory = exports.getUrl = void 0;
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
const float_1 = require("@wix/sdk-runtime/transformations/float");
const timestamp_1 = require("@wix/sdk-runtime/transformations/timestamp");
const timestamp_2 = require("@wix/sdk-runtime/transformations/timestamp");
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
const rest_modules_2 = require("@wix/sdk-runtime/rest-modules");
function resolveComWixpressMarketAimApiCheckoutUrl(opts) {
    const domainToMappings = {
        'api._api_base_domain_': [
            {
                srcPath: '/app-instance-manager-webapp',
                destPath: '',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/apps',
                destPath: '',
            },
        ],
        'wixapis.com': [
            {
                srcPath: '/apps',
                destPath: '',
            },
        ],
        'dev._base_domain_': [
            {
                srcPath: '/_api/app-instance-manager',
                destPath: '',
            },
            {
                srcPath: '/api/v1/instance',
                destPath: '/v1/instance',
            },
            {
                srcPath: '/api/v1/scripts',
                destPath: '/v1/scripts',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/_api/app-instance-manager',
                destPath: '',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/_api/app-instance-manager',
                destPath: '',
            },
        ],
        'editor._base_domain_': [
            {
                srcPath: '/_api/app-instance-manager',
                destPath: '',
            },
        ],
        'blocks._base_domain_': [
            {
                srcPath: '/_api/app-instance-manager',
                destPath: '',
            },
        ],
        'create.editorx': [
            {
                srcPath: '/_api/app-instance-manager',
                destPath: '',
            },
        ],
    };
    return (0, rest_modules_2.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_app-management_billing';
/**
 * Retrieves the URL for a Wix checkout page for the specified paid plan of your app.
 *
 *
 * This call succeeds only in case you have previously
 * [set up an external pricing page in your app's dashboard](https://dev.wix.com/docs/build-apps/build-your-app/pricing-plans/set-up-an-external-pricing-page).
 *
 * The returned checkout URL is valid for 48 hours.
 *
 * This API allows your app to manage your pricing page outside of Wix while
 * still using the standard Wix checkout flow.
 */
function getUrl(payload) {
    function __getUrl({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: float_1.transformSDKFloatToRESTFloat,
                paths: [{ path: 'chargeOverride.price' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.devcenter.checkout.v1.purchased_item',
            method: 'POST',
            methodFqn: 'com.wixpress.market.aim.api.Checkout.GetUrl',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressMarketAimApiCheckoutUrl({
                protoPath: '/v1/checkout',
                data: serializedData,
                host,
            }),
            data: serializedData,
        };
        return metadata;
    }
    return __getUrl;
}
exports.getUrl = getUrl;
/**
 * Retrieves a list of the site owner's past purchases for your app.
 *
 *
 * You don't have to explicitly pass an identifier for the Wix site as part of
 * the request, since this information is taken automatically from the context.
 *
 * The response doesn't include any details about cancellations.
 */
function getPurchaseHistory(payload) {
    function __getPurchaseHistory({ host }) {
        const metadata = {
            entityFqdn: 'wix.devcenter.checkout.v1.purchased_item',
            method: 'GET',
            methodFqn: 'com.wixpress.market.aim.api.Checkout.GetPurchaseHistory',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressMarketAimApiCheckoutUrl({
                protoPath: '/v1/checkout/history',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_2.transformRESTTimestampToSDKTimestamp,
                    paths: [{ path: 'purchases.dateCreated' }],
                },
            ]),
        };
        return metadata;
    }
    return __getPurchaseHistory;
}
exports.getPurchaseHistory = getPurchaseHistory;
/**
 * Triggers Wix to call the
 * [List Custom Charges SPI](https://dev.wix.com/docs/rest/internal-only/premium/custom-charges-spi/custom-charges-provider-v1/list-charges).
 *
 *
 * Wix doesn't use the response from _List Charges_ SPI to actually create an
 * invoice that's sent to the customer. Instead, calling _Get Metered Billing Charges_
 * allows you confirm that your integration with the Custom Charges SPI is
 * working as intended.
 */
function getMeteredBillingCharges(payload) {
    function __getMeteredBillingCharges({ host }) {
        const serializedData = (0, transform_paths_1.transformPaths)(payload, [
            {
                transformFn: timestamp_1.transformSDKTimestampToRESTTimestamp,
                paths: [{ path: 'startDate' }, { path: 'endDate' }],
            },
        ]);
        const metadata = {
            entityFqdn: 'wix.devcenter.checkout.v1.purchased_item',
            method: 'GET',
            methodFqn: 'com.wixpress.market.aim.api.Checkout.GetMeteredBillingCharges',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressMarketAimApiCheckoutUrl({
                protoPath: '/v1/metered-billing-charges',
                data: serializedData,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(serializedData),
        };
        return metadata;
    }
    return __getMeteredBillingCharges;
}
exports.getMeteredBillingCharges = getMeteredBillingCharges;
//# sourceMappingURL=devcenter-checkout-v1-purchased-item-billing.http.js.map