import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { GetMeteredBillingChargesOptions, GetMeteredBillingChargesResponse, GetPurchaseHistoryResponse, GetUrlOptions, GetUrlResponse, PurchasedItemInvoiceStatusUpdatedEnvelope } from './devcenter-checkout-v1-purchased-item-billing.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function getUrl(httpClient: HttpClient): GetUrlSignature;
interface GetUrlSignature {
    /**
     * Retrieves the URL for a Wix checkout page for the specified paid plan of your app.
     *
     *
     * This call succeeds only in case you have previously
     * [set up an external pricing page in your app's dashboard](https://dev.wix.com/docs/build-apps/build-your-app/pricing-plans/set-up-an-external-pricing-page).
     *
     * The returned checkout URL is valid for 48 hours.
     *
     * This API allows your app to manage your pricing page outside of Wix while
     * still using the standard Wix checkout flow.
     * @param - ID of your app's paid plan to retrieve the Wix checkout URL for. Check your app's dashboard
     * for a list of your app's supported product IDs.
     */
    (productId: string, options?: GetUrlOptions | undefined): Promise<GetUrlResponse>;
}
export declare function getPurchaseHistory(httpClient: HttpClient): GetPurchaseHistorySignature;
interface GetPurchaseHistorySignature {
    /**
     * Retrieves a list of the site owner's past purchases for your app.
     *
     *
     * You don't have to explicitly pass an identifier for the Wix site as part of
     * the request, since this information is taken automatically from the context.
     *
     * The response doesn't include any details about cancellations.
     */
    (): Promise<GetPurchaseHistoryResponse>;
}
/** @internal */
export declare function getMeteredBillingCharges(httpClient: HttpClient): GetMeteredBillingChargesSignature;
interface GetMeteredBillingChargesSignature {
    /**
     * Triggers Wix to call the
     * [List Custom Charges SPI](https://dev.wix.com/docs/rest/internal-only/premium/custom-charges-spi/custom-charges-provider-v1/list-charges).
     *
     *
     * Wix doesn't use the response from _List Charges_ SPI to actually create an
     * invoice that's sent to the customer. Instead, calling _Get Metered Billing Charges_
     * allows you confirm that your integration with the Custom Charges SPI is
     * working as intended.
     */
    (options?: GetMeteredBillingChargesOptions | undefined): Promise<GetMeteredBillingChargesResponse>;
}
export declare const onPurchasedItemInvoiceStatusUpdated: EventDefinition<PurchasedItemInvoiceStatusUpdatedEnvelope, "InvoiceStatusUpdated">;
export { BaseEventMetadata, Charge, ChargeOverride, GetMeteredBillingChargesOptions, GetMeteredBillingChargesRequest, GetMeteredBillingChargesResponse, GetPurchaseHistoryRequest, GetPurchaseHistoryResponse, GetSitePaymentMethodsStatusRequest, GetSitePaymentMethodsStatusResponse, GetUrlOptions, GetUrlRequest, GetUrlResponse, IdentificationData, IdentificationDataIdOneOf, InvoiceStatus, InvoiceStatusUpdated, MessageEnvelope, PaymentCycle, PurchasedItem, PurchasedItemInvoiceStatusUpdatedEnvelope, WebhookIdentityType, } from './devcenter-checkout-v1-purchased-item-billing.universal.js';
